@@ -9,6 +9,7 @@ The file system for storing and updating state variables during an experiment.
 import copy
 import logging as log
 from pprint import pformat
+import uuid
 
 import numpy as np
 from pint import Quantity
@@ -801,15 +802,18 @@ class Store:
             # divider is either a function or a dict with topology and/or config
             if isinstance(self.divider, dict):
                 divider = self.divider['divider']
-                state = {}
+                if isinstance(divider, str):
+                    divider = divider_registry.access(divider)
+                args = {}
                 if 'topology' in self.divider:
                     topology = self.divider['topology']
-                    state.update({'state': self.outer.get_values(topology)})
+                    state = self.topology_state(topology)
+                    args.update({'state': state})
                 if 'config' in self.divider:
                     config = self.divider['config']
-                    state.update({'config': config})
+                    args.update({'config': config})
 
-                return divider(self.get_value(), **state)
+                return divider(self.get_value(), **args)
             return self.divider(self.get_value())
         if self.inner:
             daughters = [{}, {}]
@@ -890,9 +894,13 @@ class Store:
                 self.value = self.default
 
     def add(self, added):
-        path = (added['key'],)
+        if added['key'] == '_unique_id':
+            path = (str(uuid.uuid1()),)
+        else:
+            path = (added['key'],)
         added_state = added['state']
 
+        # get path
         target = self.establish_path(path, {})
         self.apply_subschema_path(path)
         target.apply_defaults()
@@ -990,13 +998,23 @@ class Store:
             daughter_key = daughter['key']
             daughter_path = (daughter_key,)
 
-            # if no processes or topology provided, copy the mother's processes and topology
-            processes = daughter.get(
-                'processes', copy.deepcopy(self.get_path(mother_path).get_processes()))
-            topology = daughter.get(
-                'topology', copy.deepcopy(self.get_path(mother_path).get_topology()))
-            processes = processes or {}
-            topology = topology or {}
+            # get the daughter processes
+            if 'processes' in daughter:
+                processes = daughter['processes']
+            else:
+                # if no processes provided, copy the mother's processes
+                mother_processes = self.get_path(mother_path).get_processes()
+                processes = copy.deepcopy(mother_processes)
+                processes = processes or {}
+
+            # get the daughter topology
+            if 'topology' in daughter:
+                topology = daughter['topology']
+            else:
+                # if no topology provided, copy the mother's topology
+                mother_topology = self.get_path(mother_path).get_topology()
+                topology = copy.deepcopy(mother_topology)
+                topology = topology or {}
 
             self.generate(
                 daughter_path,
